@@ -1,153 +1,5 @@
 r'''
-# aws-lambda-ssmstringparameter module
-
-<!--BEGIN STABILITY BANNER-->---
-
-
-![Stability: Experimental](https://img.shields.io/badge/stability-Experimental-important.svg?style=for-the-badge)
-
-> All classes are under active development and subject to non-backward compatible changes or removal in any
-> future version. These are not subject to the [Semantic Versioning](https://semver.org/) model.
-> This means that while you may use them, you may need to update your source code when upgrading to a newer version of this package.
-
----
-<!--END STABILITY BANNER-->
-
-| **Reference Documentation**:| <span style="font-weight: normal">https://docs.aws.amazon.com/solutions/latest/constructs/</span>|
-|:-------------|:-------------|
-
-<div style="height:8px"></div>
-
-| **Language**     | **Package**        |
-|:-------------|-----------------|
-|![Python Logo](https://docs.aws.amazon.com/cdk/api/latest/img/python32.png) Python|`aws_solutions_constructs.aws_lambda_ssm_string_parameter`|
-|![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-lambda-ssmstringparameter`|
-|![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.lambdassmstringparameter`|
-
-## Overview
-
-This AWS Solutions Construct implements the AWS Lambda function and AWS Systems Manager Parameter Store String parameter with the least privileged permissions.
-
-Here is a minimal deployable pattern definition:
-
-Typescript
-
-```python
-import { Construct } from 'constructs';
-import { Stack, StackProps } from 'aws-cdk-lib';
-import { LambdaToSsmstringparameterProps,  LambdaToSsmstringparameter } from '@aws-solutions-constructs/aws-lambda-ssmstringparameter';
-import * as lambda from 'aws-cdk-lib/aws-lambda';
-
-const constructProps: LambdaToSsmstringparameterProps = {
-  lambdaFunctionProps: {
-    runtime: lambda.Runtime.NODEJS_20_X,
-    code: lambda.Code.fromAsset(`lambda`),
-    handler: 'index.handler'
-  },
-  stringParameterProps: { stringValue: "test-string-value" }
-};
-
-new LambdaToSsmstringparameter(this, 'test-lambda-ssmstringparameter-stack', constructProps);
-```
-
-Python
-
-```python
-from aws_solutions_constructs.aws_lambda_ssmstringparameter import LambdaToSsmstringparameter
-from aws_cdk import (
-    aws_lambda as _lambda,
-    aws_ssm as ssm,
-    Stack
-)
-from constructs import Construct
-
-LambdaToSsmstringparameter(
-    self, 'test-lambda-ssmstringparameter-stack',
-    lambda_function_props=_lambda.FunctionProps(
-        code=_lambda.Code.from_asset('lambda'),
-        runtime=_lambda.Runtime.PYTHON_3_11,
-        handler='index.handler'
-    ),
-    string_parameter_props=ssm.StringParameterProps(
-        string_value="test-string-value")
-)
-```
-
-Java
-
-```java
-import software.constructs.Construct;
-
-import software.amazon.awscdk.Stack;
-import software.amazon.awscdk.StackProps;
-import software.amazon.awscdk.services.lambda.*;
-import software.amazon.awscdk.services.lambda.Runtime;
-import software.amazon.awscdk.services.ssm.*;
-import software.amazon.awsconstructs.services.lambdassmstringparameter.*;
-
-new LambdaToSsmstringparameter(this, "test-lambda-ssmstringparameter-stack",
-        new LambdaToSsmstringparameterProps.Builder()
-                .lambdaFunctionProps(new FunctionProps.Builder()
-                        .runtime(Runtime.NODEJS_20_X)
-                        .code(Code.fromAsset("lambda"))
-                        .handler("index.handler")
-                        .build())
-                .stringParameterProps(new StringParameterProps.Builder()
-                        .stringValue("test-string-value")
-                        .build())
-                .build());
-```
-
-## Pattern Construct Props
-
-| **Name**     | **Type**        | **Description** |
-|:-------------|:----------------|-----------------|
-|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_lambda.Function.html)|Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.|
-|lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_lambda.FunctionProps.html)|User provided props to override the default props for the Lambda function.|
-|existingStringParameterObj?|[`ssm.StringParameter`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_ssm.StringParameter.html)|Existing instance of SSM String parameter object, providing both this and `stringParameterProps` will cause an error|
-|stringParameterProps?|[`ssm.StringParameterProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_ssm.StringParameterProps.html)|Optional user provided props to override the default props for SSM String parameter. If existingStringParameterObj is not set stringParameterProps is required. The only supported [`ssm.StringParameterProps.type`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_ssm.StringParameterProps.html#type) is [`STRING`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_ssm.ParameterType.html#string) if a different value is provided it will be overridden.|
-|stringParameterEnvironmentVariableName?|`string`|Optional Name for the Lambda function environment variable set to the name of the parameter. Default: SSM_STRING_PARAMETER_NAME |
-|existingVpc?|[`ec2.IVpc`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_ec2.IVpc.html)|An optional, existing VPC into which this pattern should be deployed. When deployed in a VPC, the Lambda function will use ENIs in the VPC to access network resources and an Interface Endpoint will be created in the VPC for AWS Systems Manager Parameter. If an existing VPC is provided, the `deployVpc` property cannot be `true`. This uses `ec2.IVpc` to allow clients to supply VPCs that exist outside the stack using the [`ec2.Vpc.fromLookup()`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_ec2.Vpc.html#static-fromwbrlookupscope-id-options) method.|
-|vpcProps?|[`ec2.VpcProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_ec2.VpcProps.html)|Optional user-provided properties to override the default properties for the new VPC. `enableDnsHostnames`, `enableDnsSupport`, `natGateways` and `subnetConfiguration` are set by the pattern, so any values for those properties supplied here will be overridden. If `deployVpc` is not `true` then this property will be ignored.|
-|deployVpc?|`boolean`|Whether to create a new VPC based on `vpcProps` into which to deploy this pattern. Setting this to true will deploy the minimal, most private VPC to run the pattern:<ul><li> One isolated subnet in each Availability Zone used by the CDK program</li><li>`enableDnsHostnames` and `enableDnsSupport` will both be set to true</li></ul>If this property is `true` then `existingVpc` cannot be specified. Defaults to `false`.|
-|stringParameterPermissions|`string`|Optional SSM String parameter permissions to grant to the Lambda function. One of the following may be specified: "Read", "ReadWrite".
-
-## Pattern Properties
-
-| **Name**     | **Type**        | **Description** |
-|:-------------|:----------------|-----------------|
-|lambdaFunction|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_lambda.Function.html)|Returns an instance of lambda.Function created by the construct|
-|stringParameter|[`ssm.StringParameter`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_ssm.StringParameter.html)|Returns an instance of ssm.StringParameter created by the construct|
-|vpc?|[`ec2.IVpc`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_ec2.IVpc.html)|Returns an interface on the VPC used by the pattern (if any). This may be a VPC created by the pattern or the VPC supplied to the pattern constructor.|
-
-## Default settings
-
-Out of the box implementation of the Construct without any override will set the following defaults:
-
-### AWS Lambda Function
-
-* Configure limited privilege access IAM role for Lambda function
-* Enable reusing connections with Keep-Alive for NodeJs Lambda function
-* Enable X-Ray Tracing
-* Set Environment Variables
-
-  * (default) SSM_STRING_PARAMETER_NAME
-  * AWS_NODEJS_CONNECTION_REUSE_ENABLED (for Node 10.x and higher functions)
-
-### Amazon AWS Systems Manager Parameter Store String
-
-* Enable read-only access for the associated AWS Lambda Function
-* Creates a new SSM String parameter with the values provided
-* Retain the SSM String parameter when deleting the CloudFormation stack
-
-## Architecture
-
-![Architecture Diagram](architecture.png)
-
----
-
-
-© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+Documentation for this pattern can be found [here](https://github.com/awslabs/aws-solutions-constructs/blob/main/source/patterns/%40aws-solutions-constructs/aws-lambda-ssmstringparameter/README.adoc)
 '''
 from pkgutil import extend_path
 __path__ = extend_path(__path__, __name__)
@@ -215,10 +67,10 @@ class LambdaToSsmstringparameter(
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
         :param deploy_vpc: Whether to deploy a new VPC. Default: - false
-        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
+        :param existing_lambda_obj: Optional - instance of an existing Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
         :param existing_string_parameter_obj: Existing instance of SSM String parameter object, If this is set then the stringParameterProps is ignored. Default: - Default props are used
         :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
-        :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default properties are used.
+        :param lambda_function_props: Optional - user provided props to override the default props for the Lambda function. Providing both this and ``existingLambdaObj`` is an error. Default: - Default properties are used.
         :param string_parameter_environment_variable_name: Optional Name for the Lambda function environment variable set to the name of the parameter. Default: - SSM_STRING_PARAMETER_NAME
         :param string_parameter_permissions: Optional SSM String parameter permissions to grant to the Lambda function. One of the following may be specified: "Read", "ReadWrite". Default: - Read access is given to the Lambda function if no value is specified.
         :param string_parameter_props: Optional user provided props to override the default props for SSM String parameter. If existingStringParameterObj is not set stringParameterProps is required. The only supported string parameter type is ParameterType.STRING. Default: - Default props are used
@@ -293,10 +145,10 @@ class LambdaToSsmstringparameterProps:
     ) -> None:
         '''
         :param deploy_vpc: Whether to deploy a new VPC. Default: - false
-        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
+        :param existing_lambda_obj: Optional - instance of an existing Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
         :param existing_string_parameter_obj: Existing instance of SSM String parameter object, If this is set then the stringParameterProps is ignored. Default: - Default props are used
         :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
-        :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default properties are used.
+        :param lambda_function_props: Optional - user provided props to override the default props for the Lambda function. Providing both this and ``existingLambdaObj`` is an error. Default: - Default properties are used.
         :param string_parameter_environment_variable_name: Optional Name for the Lambda function environment variable set to the name of the parameter. Default: - SSM_STRING_PARAMETER_NAME
         :param string_parameter_permissions: Optional SSM String parameter permissions to grant to the Lambda function. One of the following may be specified: "Read", "ReadWrite". Default: - Read access is given to the Lambda function if no value is specified.
         :param string_parameter_props: Optional user provided props to override the default props for SSM String parameter. If existingStringParameterObj is not set stringParameterProps is required. The only supported string parameter type is ParameterType.STRING. Default: - Default props are used
@@ -354,7 +206,7 @@ class LambdaToSsmstringparameterProps:
     def existing_lambda_obj(
         self,
     ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function]:
-        '''Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
+        '''Optional - instance of an existing Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error.
 
         :default: - None
         '''
@@ -382,7 +234,9 @@ class LambdaToSsmstringparameterProps:
     def lambda_function_props(
         self,
     ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.FunctionProps]:
-        '''User provided props to override the default props for the Lambda function.
+        '''Optional - user provided props to override the default props for the Lambda function.
+
+        Providing both this and ``existingLambdaObj`` is an error.
 
         :default: - Default properties are used.
         '''
